<?php namespace EscapeWork\Manager\News\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\News\Repositories\NewsCategory\NewsCategoryRepository;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class NewsCategoriesController extends ManagerController
{

    public function __construct(NewsCategoryRepository $newsCategory)
    {
        $this->newsCategory = $newsCategory;

        # filters
        $this->enableDefaultFilters('news');
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $view                 = View::make(Config::get('manager-news::views.news_categories.index'));
        $view->newsCategories = $this->newsCategory->paginate(20);

        return $view;
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $this->newsCategory->fill(Input::old());

        $view               = View::make(Config::get('manager-news::views.news_categories.form'));
        $view->newsCategory = $this->newsCategory;
        $view->edit         = false;

        return $view;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $this->newsCategory->fill(Input::all());

        if (! $this->newsCategory->validate()) {
            return Redirect::route('manager.noticias.categorias.create')
                        ->withInput()
                        ->withErrors($this->newsCategory->getValidationErrors());
        }

        $this->newsCategory->save();

        return Redirect::route('manager.noticias.categorias.index')->with('message', 'A categoria <strong>' . $this->newsCategory->category . '</strong> foi inserida com sucesso!');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @return Response
     */
    public function edit($id)
    {
        $this->newsCategory = $this->newsCategory->findOrFail($id);

        Msg::setInfo('Editando a categoria <strong>' . $this->newsCategory->category . '</strong>');

        $view                = View::make(Config::get('manager-news::views.news_categories.form'));
        $view->newsCategory  = $this->newsCategory;
        $view->edit          = true;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function update($id)
    {
        $this->newsCategory = $this->newsCategory->findOrFail($id);
        $this->newsCategory->fill(Input::all());

        if (! $this->newsCategory->validate()) {
            return Redirect::route('manager.noticias.categorias.edit', array($this->newsCategory->id))
                    ->withInput()
                    ->withErrors($this->newsCategory->getValidationErrors());
        }

        $this->newsCategory->save();

        return Redirect::route('manager.noticias.categorias.index')
                ->with('message', 'A categoria <strong>'.$this->newsCategory->category.'</strong> foi editada com sucesso!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return Response
     */
    public function destroy($id)
    {
        $this->newsCategory = $this->newsCategory->findOrFail($id);
        $this->newsCategory->destroy($id);

        return Redirect::route('manager.noticias.categorias.index')
                ->with('message', 'A categoria <strong>'.$this->newsCategory->category.'</strong> foi excluída com sucesso!');
    }
}
