<?php namespace EscapeWork\Manager\News\Repositories\News;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\News\Models\News;

class EloquentNewsRepository extends BaseEloquentRepository implements NewsRepository
{

    /**
     * Valid orderBy fields
     */
    protected $orderByFields = array(
        'news.id',
        'news.title',
        'news.date',
        'news_categories.category',
    );

    public function __construct(News $news)
    {
        $this->model = $news;
    }

    public function filterAndPaginate(array $params = array())
    {
        $query = $this->model
                      ->select('news.*', 'news_categories.category')
                      ->leftJoinCategories();

        if (isset($params['title']) && $params['title'] != '') {
            $query->where('news.title', 'like', '%'.$params['title'].'%');
        }

        if (isset($params['category_id']) && $params['category_id'] != '') {
            $query->orWhere('news.news_category_id', '=', $params['category_id']);
        }

        $this->configureOrderBy($query, $params, 'date', 'desc');

        return $query->paginate();
    }
}
